---
# https://vitepress.dev/reference/default-theme-home-page
layout: home

hero:
  name: "PAGETools"
  text: "Python powered PAGE XML toolkit"
  tagline: 
  actions:
    - theme: brand
      text: Installation
      link: /installation
    - theme: alt
      text: Tools
      link: /tools/

features:
  - title: Analytics
    details: Analyze your PAGE XML datasets regarding various metrics
  - title: Management
    details: Easily manage your PAGE XML dataset through the CLI 
  - title: Transformations
    details: Extract data from your existing PAGE files, generate new PAGE XML datasets and much more 
---

